@@ -7,27 +7,33 @@ logger = logging.getLogger(__name__)
 
 class RouteState(object):
     def __init__(self, request):
-        self._prefixes = []
+        self._prefixes = ()
         # matched subdomain with aliases replaced by their main value
-        self.primary_subdomains = []
+        self.primary_subdomains = () # tuple to be sure it's readonly
         self.primary_domain = ''
         # remaining subdomain part for match
         self._domain = request.host.split(':', 1)[0].decode('idna')
         self.subdomain = self._domain
         self.request = request
 
-    def add_prefix(self, prefix):
-        self._prefixes.append(prefix)
+    def __copy__(self):
+        copy = object.__new__(type(self))
+        copy.__dict__.update(self.__dict__)
+        return copy
 
-    def pop_prefix(self):
-        self._prefixes.pop()
+    def add_prefix(self, prefix):
+        self = self.__copy__()
+        self._prefixes += (prefix,)
+        return self
 
     def add_subdomain(self, subdomain, alias_matched):
+        self = self.__copy__()
         if subdomain:
-            self.primary_subdomains.insert(0, subdomain)
+            self.primary_subdomains = (subdomain, ) + self.primary_subdomains
             self.primary_domain = '.'.join(self.primary_subdomains)
         if alias_matched:
             self.subdomain = self.subdomain[:-len(alias_matched)].rstrip('.')
+        return self
 
     @property
     def path(self):
